==> hj_check_os_version-0.3.6-py3-none-any.whl: hj_check_os_version/hi.py <==
art = """
==========----------------:::::::::::::::::::::::::::::::::::::-----------=++++++++++=-------------=
=============---------------:::::::::::-+*+-:-=+++*++==--#%%*-:-----------=++++++++++=--------------
=================------------::::::::-*@@@@@@@@@@@@@@@@@@@@@@@%+----------=++++++++++=--------------
=====================----------:::::+%@@@@@@@@@@@@@@@@@@@@@@@@@@%---------=++++++++++=--------------
=========================--------=%@@@@@@@%%@@@@%----*@@@@+--+@@@@=-------=++++++++++=--------------
=========================-==---+%@@@@@@%=---=#@@#-----+%#------*%*=-------=++++++++++=--------------
============================-=%@@@##%%#=----------------------------------=+++++**+++=--------------
============================+@@@%=----------------------------------------=++**++++++=--------------
===========================*@@@@+-----------------------=-----------------=++++++++++=--------------
==========================+@@@@#---=------*%%%#+---------+%%###+-----------=+++++++++---------------
==========================%@@@@*--=----=%@+:..=%@+-----=%@+...-@@=------------+++++++---------------
-------------------------*@@@@%-------=%@+....-%@@-----*@@#:.-#@@#-------------=+++++-:-------------
---------===+===-------==+*%@@%-------+@@@%%%@*+@%-----=%@@##@@@@=---------------++++-::------------
----------=====------==------%*--------*%@@@#%@@#--------=#%%%#+-----------------++++-----------====
--------===---------=---------=-----------=++==----------------------------------=++++++++**********
---------------------------------------------------------------------------------=+++*************++
-------------------=---------------------------------------====------------------=++++++++=======+++
-------------------=-----------------------------------=**######**+----------------:::--===========+
-------------------=----------------------------------*############*=-----------=::::::::::-=+======
--------------------=--------------------------------+###############=---------=-=-::::::::::::-====
---------------------=-------+*++==------------------*###############*-------=------=---::::::::::::
------------------------=**************++===---------=*##############+-----=------------=---::::::::
------------------------=**********************++++===+*############*==+++------------------=---::::
------------------------=************************************************+---------------------==---
------------------------=************************************************+-------------------------=
-------------------------+***********************************************+-----------------==-------
-------------------------=***********************************************+-------------====---------
-------------------------=***********************************************+--------------==----------
-------------------------+***********************************************+--------------------------
-------------------------=***********************************************+--------------------------

"""


import random
from check_os_ver.hi import hi as hi1
from cho_check_os_ver.hi import hi as hi2
from jacob_os_version_check.hi import hi as hi3
from lucas_check_os_ver.hi import hi as hi4
from stundrg_check_os_ver.hi import hi as hi5
from nunininu_check_os_ver.hi import hi as hi6
from seo_check_os_version.hi import hi as hi7
from ppabam_check_os_ver.hi import hi as hi8

def hi():
    return(art)

def random_pic():
    arts_list = [hi1, hi2, hi3, hi4, 
                 hi5, 
                 hi6, hi7, hi8]
    pick_hi = random.choice(arts_list)()
    return(pick_hi)

==> hj_check_os_version-0.3.7-py3-none-any.whl: hj_check_os_version/hi.py <==
art = """
==========----------------:::::::::::::::::::::::::::::::::::::-----------=++++++++++=-------------=
=============---------------:::::::::::-+*+-:-=+++*++==--#%%*-:-----------=++++++++++=--------------
=================------------::::::::-*@@@@@@@@@@@@@@@@@@@@@@@%+----------=++++++++++=--------------
=====================----------:::::+%@@@@@@@@@@@@@@@@@@@@@@@@@@%---------=++++++++++=--------------
=========================--------=%@@@@@@@%%@@@@%----*@@@@+--+@@@@=-------=++++++++++=--------------
=========================-==---+%@@@@@@%=---=#@@#-----+%#------*%*=-------=++++++++++=--------------
============================-=%@@@##%%#=----------------------------------=+++++**+++=--------------
============================+@@@%=----------------------------------------=++**++++++=--------------
===========================*@@@@+-----------------------=-----------------=++++++++++=--------------
==========================+@@@@#---=------*%%%#+---------+%%###+-----------=+++++++++---------------
==========================%@@@@*--=----=%@+:..=%@+-----=%@+...-@@=------------+++++++---------------
-------------------------*@@@@%-------=%@+....-%@@-----*@@#:.-#@@#-------------=+++++-:-------------
---------===+===-------==+*%@@%-------+@@@%%%@*+@%-----=%@@##@@@@=---------------++++-::------------
----------=====------==------%*--------*%@@@#%@@#--------=#%%%#+-----------------++++-----------====
--------===---------=---------=-----------=++==----------------------------------=++++++++**********
---------------------------------------------------------------------------------=+++*************++
-------------------=---------------------------------------====------------------=++++++++=======+++
-------------------=-----------------------------------=**######**+----------------:::--===========+
-------------------=----------------------------------*############*=-----------=::::::::::-=+======
--------------------=--------------------------------+###############=---------=-=-::::::::::::-====
---------------------=-------+*++==------------------*###############*-------=------=---::::::::::::
------------------------=**************++===---------=*##############+-----=------------=---::::::::
------------------------=**********************++++===+*############*==+++------------------=---::::
------------------------=************************************************+---------------------==---
------------------------=************************************************+-------------------------=
-------------------------+***********************************************+-----------------==-------
-------------------------=***********************************************+-------------====---------
-------------------------=***********************************************+--------------==----------
-------------------------+***********************************************+--------------------------
-------------------------=***********************************************+--------------------------

"""


import random
from check_os_ver.hi import hi as hi1
from cho_check_os_ver.hi import hi as hi2
from jacob_os_version_check.hi import hi as hi3
from lucas_check_os_ver.hi import hi as hi4
#from stundrg_check_os_ver.hi import hi as hi5
from nunininu_check_os_ver.hi import hi as hi6
from seo_check_os_version.hi import hi as hi7
from ppabam_check_os_ver.hi import hi as hi8

def hi():
    return(art)

def random_pic():
    arts_list = [hi1, hi2, hi3, hi4, 
                 #hi5, 
                 hi6, hi7, hi8]
    pick_hi = random.choice(arts_list)()
    return(pick_hi)
